@@ -1,6 +1,6 @@
 from social.p3 import quote
 from social.utils import sanitize_redirect, user_is_authenticated, \
-                         user_is_active, partial_pipeline_data
+                         user_is_active, partial_pipeline_data, setting_url
 
 
 def do_auth(strategy, redirect_name='next'):
@@ -34,21 +34,11 @@ def do_complete(strategy, login, user=None, redirect_name='next',
 
     is_authenticated = user_is_authenticated(user)
     user = is_authenticated and user or None
-    default_redirect = strategy.setting('LOGIN_REDIRECT_URL')
-    url = default_redirect
-    login_error_url = strategy.setting('LOGIN_ERROR_URL') or \
-                      strategy.setting('LOGIN_URL')
 
     partial = partial_pipeline_data(strategy, user, *args, **kwargs)
-    if partial is not None:
-        idx, backend, xargs, xkwargs = partial
-        if backend == strategy.backend.name:
-            user = strategy.continue_pipeline(pipeline_index=idx,
-                                              *xargs, **xkwargs)
-        else:
-            strategy.clean_partial_pipeline()
-            user = strategy.complete(user=user, request=strategy.request,
-                                     *args, **kwargs)
+    if partial:
+        xargs, xkwargs = partial
+        user = strategy.continue_pipeline(*xargs, **xkwargs)
     else:
         user = strategy.complete(user=user, request=strategy.request,
                                  *args, **kwargs)
@@ -58,11 +48,11 @@ def do_complete(strategy, login, user=None, redirect_name='next',
 
     if is_authenticated:
         if not user:
-            url = redirect_value or default_redirect
+            url = setting_url(strategy, redirect_value, 'LOGIN_REDIRECT_URL')
         else:
-            url = redirect_value or \
-                  strategy.setting('NEW_ASSOCIATION_REDIRECT_URL') or \
-                  default_redirect
+            url = setting_url(strategy, redirect_value,
+                              'NEW_ASSOCIATION_REDIRECT_URL',
+                              'LOGIN_REDIRECT_URL')
     elif user:
         if user_is_active(user):
             # catch is_new/social_user in case login() resets the instance
@@ -73,22 +63,24 @@ def do_complete(strategy, login, user=None, redirect_name='next',
             strategy.session_set('social_auth_last_login_backend',
                                  social_user.provider)
 
-            # Remove possible redirect URL from session, if this is a new
-            # account, send him to the new-users-page if defined.
-            new_user_redirect = strategy.setting('NEW_USER_REDIRECT_URL')
-            if new_user_redirect and is_new:
-                url = new_user_redirect
+            if is_new:
+                url = setting_url(strategy, redirect_value,
+                                  'NEW_USER_REDIRECT_URL',
+                                  'LOGIN_REDIRECT_URL')
             else:
-                url = redirect_value or default_redirect
+                url = setting_url(strategy, redirect_value,
+                                  'LOGIN_REDIRECT_URL')
         else:
-            url = strategy.setting('INACTIVE_USER_URL', login_error_url)
+            url = setting_url(strategy, 'INACTIVE_USER_URL', 'LOGIN_ERROR_URL',
+                              'LOGIN_URL')
     else:
-        url = login_error_url
+        url = setting_url(strategy, 'LOGIN_ERROR_URL', 'LOGIN_URL')
 
     if redirect_value and redirect_value != url:
         redirect_value = quote(redirect_value)
         url += ('?' in url and '&' or '?') + \
                '{0}={1}'.format(redirect_name, redirect_value)
+
     if strategy.setting('SANITIZE_REDIRECTS', True):
         url = sanitize_redirect(strategy.request_host(), url) or \
               strategy.setting('LOGIN_REDIRECT_URL')
@@ -98,21 +90,19 @@ def do_complete(strategy, login, user=None, redirect_name='next',
 def do_disconnect(strategy, user, association_id=None, redirect_name='next',
                   *args, **kwargs):
     partial = partial_pipeline_data(strategy, user, *args, **kwargs)
-    out = None
-    if partial is not None:
-        idx, backend, xargs, xkwargs = partial
-        if backend == strategy.backend.name:
-            out = strategy.disconnect(pipeline_index=idx, user=user,
-                                      association_id=association_id,
-                                      *args, **kwargs)
-    if out is None:
-        strategy.clean_partial_pipeline()
-        out = strategy.disconnect(user=user, association_id=association_id,
-                                  *args, **kwargs)
-    if not isinstance(out, dict):
-        return out
+    if partial:
+        xargs, xkwargs = partial
+        response = strategy.disconnect(association_id=association_id,
+                                       *xargs, **xkwargs)
     else:
-        data = strategy.request_data()
-        return strategy.redirect(data.get(redirect_name, '') or
-                                 strategy.setting('DISCONNECT_REDIRECT_URL') or
-                                 strategy.setting('LOGIN_REDIRECT_URL'))
+        response = strategy.disconnect(user=user,
+                                       association_id=association_id,
+                                       *args, **kwargs)
+
+    if isinstance(response, dict):
+        response = strategy.redirect(
+            strategy.request_data().get(redirect_name, '') or
+            strategy.setting('DISCONNECT_REDIRECT_URL') or
+            strategy.setting('LOGIN_REDIRECT_URL')
+        )
+    return response
