@@ -1,17 +1,6 @@
-"""
-Base backends classes.
-
-This module defines base classes needed to define custom OpenID or OAuth1/2
-auth services from third parties. This customs must subclass an Auth and a
-Backend class, check current implementation for examples.
-
-Also the modules *must* define a BACKENDS dictionary with the backend name
-(which is used for URLs matching) and Auth class, otherwise it won't be
-enabled.
-"""
 from requests import request
 
-from social.utils import setting_name, module_member, parse_qs
+from social.utils import module_member, parse_qs
 
 
 class BaseAuth(object):
@@ -20,6 +9,7 @@ class BaseAuth(object):
     name = ''  # provider name, it's stored in database
     supports_inactive_user = False  # Django auth
     ID_KEY = None
+    EXTRA_DATA = None
     REQUIRES_EMAIL_VALIDATION = False
 
     def __init__(self, strategy=None, redirect_uri=None, *args, **kwargs):
@@ -34,12 +24,7 @@ class BaseAuth(object):
 
     def setting(self, name, default=None):
         """Return setting value from strategy"""
-        _default = object()
-        for name in (setting_name(self.name, name), name):
-            value = self.strategy.setting(name, _default)
-            if value != _default:
-                return value
-        return default
+        return self.strategy.setting(name, default=default, backend=self)
 
     def auth_url(self):
         """Must return redirect URL to auth provider"""
@@ -117,8 +102,25 @@ class BaseAuth(object):
         return out
 
     def extra_data(self, user, uid, response, details):
-        """Return default blank user extra data"""
-        return {}
+        """Return deafault extra data to store in extra_data field"""
+        data = {}
+        for entry in (self.EXTRA_DATA or []) + self.setting('EXTRA_DATA', []):
+            if not isinstance(entry, (list, tuple)):
+                entry = (entry,)
+            size = len(entry)
+            if size >= 1 and size <= 3:
+                if size == 3:
+                    name, alias, discard = entry
+                elif size == 2:
+                    (name, alias), discard = entry, False
+                elif size == 1:
+                    name = alias = entry[0]
+                    discard = False
+                value = response.get(name) or details.get(name)
+                if discard and not value:
+                    continue
+                data[alias] = value
+        return data
 
     def auth_allowed(self, response, details):
         """Return True if the user should be allowed to authenticate, by
@@ -133,7 +135,8 @@ class BaseAuth(object):
         return allowed
 
     def get_user_id(self, details, response):
-        """Must return a unique ID from values returned on details"""
+        """Return a unique ID for the current user, by default from server
+        response."""
         return response.get(self.ID_KEY)
 
     def get_user_details(self, response):
