@@ -1,7 +1,6 @@
 """
-Fedora OpenID support
-
-No extra configurations are needed to make this work.
+Fedora OpenId backend, docs at:
+    http://psa.matiasaguirre.net/docs/backends/fedora.html
 """
 from social.backends.open_id import OpenIdAuth
 
